;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "wisp-mode" "20251108.2318"
  "Tools for wisp: the Whitespace-to-Lisp preprocessor."
  '((emacs "24.4"))
  :url "http://www.draketo.de/english/wisp"
  :commit "cfebcd5f097f2f7bbb0f5b0c3730584313c93bac"
  :revdesc "cfebcd5f097f"
  :keywords '("languages" "lisp" "scheme")
  :authors '(("Arne Babenhauserheide" . "arne_bab@web.de"))
  :maintainers '(("Arne Babenhauserheide" . "arne_bab@web.de")))
